@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 
 from pydantic import validate_arguments
-from cerberus import Validator
 from validator_collection import validators, checkers, errors
 
 from el_logging import logger
@@ -156,7 +155,7 @@ def is_attr_empty(obj: object, attr_name: str):
     """
 
     try:
-        if is_empty(obj):
+        if (not isinstance(obj, dict)) and is_empty(obj):
             raise ValueError("'obj' argument value is empty!")
 
         attr_name = attr_name.strip()
@@ -166,6 +165,18 @@ def is_attr_empty(obj: object, attr_name: str):
         logger.error(err)
         raise
 
+    if isinstance(obj, dict):
+        if len(obj) == 0:
+            return True
+
+        if not attr_name in obj:
+            return True
+
+        _val = obj[attr_name]
+        if is_empty(_val):
+            return True
+        return False
+
     try:
         _val = getattr(obj, attr_name)
     except AttributeError:
